@@ -34,6 +34,7 @@ sort_db_names <- function(db_names, decreasing=FALSE)
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### get_db_fasta_file()
+### get_original_db_fasta_files()
 ###
 
 ### Note that the returned path is NOT guaranteed to exist.
@@ -44,6 +45,22 @@ get_db_fasta_file <- function(db_path, region_type=c(VDJ_REGION_TYPES, "C"))
     file.path(db_path, paste0(region_type, ".fasta"))
 }
 
+### Unlike with get_db_fasta_file(), the paths returned by
+### get_original_db_fasta_files() are guaranteed to exist.
+get_original_db_fasta_files <-
+    function(db_path, region_type=c(VDJ_REGION_TYPES, "C"))
+{
+    stopifnot(isSingleNonWhiteString(db_path), dir.exists(db_path))
+    region_type <- match.arg(region_type)
+    subdir <- paste0(region_type, "_original_fasta")
+    original_fasta_dir <- file.path(db_path, subdir)
+    stopifnot(dir.exists(original_fasta_dir))
+    fasta_files <- list.files(original_fasta_dir, pattern="\\.fasta$",
+                              full.names=TRUE)
+    stopifnot(length(fasta_files) != 0L)
+    fasta_files
+}
+
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### .tabulate_dbs_by_region_type()
@@ -82,20 +99,17 @@ get_db_fasta_file <- function(db_path, region_type=c(VDJ_REGION_TYPES, "C"))
 
 ### Returns a named integer vector with 'loci' as names.
 .tabulate_db_original_fasta_files_by_locus <-
-    function(original_fasta_dir, loci)
+    function(db_path, region_type, loci)
 {
-    stopifnot(isSingleNonWhiteString(original_fasta_dir),
-              dir.exists(original_fasta_dir))
-    fasta_files <- list.files(original_fasta_dir, pattern="\\.fasta$")
-    stopifnot(length(fasta_files) != 0L)
-    found_loci <- substr(fasta_files, 1L, 3L)
+    fasta_files <- get_original_db_fasta_files(db_path, region_type)
+    found_loci <- substr(basename(fasta_files), 1L, 3L)
     stopifnot(all(found_loci %in% loci))
     fasta_files <- setNames(fasta_files[match(loci, found_loci)], loci)
     vapply(fasta_files,
         function(fasta_file) {
             if (is.na(fasta_file))
                 return(0L)
-            length(fasta.seqlengths(file.path(original_fasta_dir, fasta_file)))
+            length(fasta.seqlengths(fasta_file))
         }, integer(1))
 }
 
@@ -104,13 +118,11 @@ get_db_fasta_file <- function(db_path, region_type=c(VDJ_REGION_TYPES, "C"))
 .tabulate_germline_db_by_group <- function(db_path, loci)
 {
     stopifnot(isSingleNonWhiteString(db_path))
-    stop_if_bad_loci(loci)
+    stop_if_malformed_loci_vector(loci)
     vdj_counts <- lapply(VDJ_REGION_TYPES,
-        function(region_type) {
-            basename <- paste0(region_type, "_original_fasta")
-            original_fasta_dir <- file.path(db_path, basename)
-            .tabulate_db_original_fasta_files_by_locus(original_fasta_dir, loci)
-        }
+        function(region_type)
+            .tabulate_db_original_fasta_files_by_locus(db_path, region_type,
+                                                       loci)
     )
     ans <- do.call(cbind, vdj_counts)
     stopifnot(all(rowSums(ans) != 0L), all(colSums(ans) != 0L))
@@ -122,9 +134,8 @@ get_db_fasta_file <- function(db_path, region_type=c(VDJ_REGION_TYPES, "C"))
 .tabulate_c_region_db_by_locus <- function(db_path, loci)
 {
     stopifnot(isSingleNonWhiteString(db_path))
-    stop_if_bad_loci(loci)
-    original_fasta_dir <- file.path(db_path, "C_original_fasta")
-    ans <- .tabulate_db_original_fasta_files_by_locus(original_fasta_dir, loci)
+    stop_if_malformed_loci_vector(loci)
+    ans <- .tabulate_db_original_fasta_files_by_locus(db_path, "C", loci)
     stopifnot(all(ans != 0L))
     ans
 }
@@ -167,13 +178,15 @@ get_db_fasta_file <- function(db_path, region_type=c(VDJ_REGION_TYPES, "C"))
 
 ### 'long.listing' is ignored when 'names.only' is TRUE.
 list_dbs <- function(dbs_home, what=c("germline", "C-region"),
-                     builtin.only=FALSE,
+                     builtin.only=FALSE, with.intdata.only=FALSE,
                      names.only=FALSE, long.listing=FALSE)
 {
     stopifnot(isSingleNonWhiteString(dbs_home), dir.exists(dbs_home))
     what <- match.arg(what)
     if (!isTRUEorFALSE(builtin.only))
         stop(wmsg("'builtin.only' must be TRUE or FALSE"))
+    if (!isTRUEorFALSE(with.intdata.only))
+        stop(wmsg("'with.intdata.only' must be TRUE or FALSE"))
     if (!isTRUEorFALSE(names.only))
         stop(wmsg("'names.only' must be TRUE or FALSE"))
     if (!isTRUEorFALSE(long.listing))
@@ -185,13 +198,24 @@ list_dbs <- function(dbs_home, what=c("germline", "C-region"),
     if (builtin.only)
         db_names <- db_names[has_prefix(db_names, "_")]
     db_names <- sort_db_names(db_names)
+    if (what == "germline") {
+        intdata_dirs <- file.path(dbs_home, db_names, "internal_data")
+        intdata <- dir.exists(intdata_dirs)  # logical vector
+        if (with.intdata.only) {
+            db_names <- db_names[intdata]
+            intdata <- intdata[intdata]  # keep only TRUEs
+        }
+    }
     if (names.only)
         return(db_names)
     if (!long.listing) {
         region_types <- if (what == "germline") VDJ_REGION_TYPES else "C"
         basic_stats <- .tabulate_dbs_by_region_type(dbs_home, db_names,
                                                     region_types)
-        return(data.frame(db_name=db_names, basic_stats))
+        ans <- data.frame(db_name=db_names, basic_stats)
+        if (what == "germline")
+            ans <- cbind(ans, intdata=intdata)
+        return(ans)
     }
     if (what == "germline") {
         .make_long_listing_for_germline_dbs(dbs_home, db_names)
